@@ -11,12 +11,14 @@ class LidarsAndCamerasSequence(CreateableInputAPIResource):
 
     path = 'lidars-and-cameras-sequence'
 
-    def create(self,
-               lidars_and_cameras_sequence: InputModel.LidarsAndCamerasSequence,
-               project: Optional[str] = None,
-               batch: Optional[str] = None,
-               annotation_types: Optional[List[str]] = None,
-               dryrun: bool = False) -> Optional[InputModel.CreateInputResponse]:
+    def create(
+        self,
+        lidars_and_cameras_sequence: InputModel.LidarsAndCamerasSequence,
+        project: Optional[str] = None,
+        batch: Optional[str] = None,
+        annotation_types: Optional[List[str]] = None,
+        dryrun: bool = False
+    ) -> Optional[InputModel.CreateInputResponse]:
         """
         Upload files and create an input of type ``LidarsAndCamerasSequence``.
 
@@ -28,13 +30,12 @@ class LidarsAndCamerasSequence(CreateableInputAPIResource):
         :returns InputJobCreated: Class containing id of the created input job, or `None` if dryrun.
         """
 
+        imu_data = lidars_and_cameras_sequence.imu_data
         payload = lidars_and_cameras_sequence.to_dict()
 
-        response = self._post_input_request(self.path, payload,
-                                            project=project,
-                                            batch=batch,
-                                            annotation_types=annotation_types,
-                                            dryrun=dryrun)
+        response = self._post_input_request(
+            self.path, payload, project=project, batch=batch, annotation_types=annotation_types, imu_data=imu_data, dryrun=dryrun
+        )
 
         if dryrun:
             return None
